Basic Steps
===========

.. toctree::
    :maxdepth: 2

.. currentmodule:: aloe_webdriver

.. code-block:: python

    import aloe_webdriver

Navigation
----------

.. autofunction:: visit
.. autofunction:: url_should_be
.. autofunction:: url_should_contain
.. autofunction:: url_should_not_contain
.. autofunction:: page_title

Text
----

.. autofunction:: should_see
.. autofunction:: should_see_in_seconds
.. autofunction:: should_not_see

Links
-----

.. autofunction:: click
.. autofunction:: should_see_link
.. autofunction:: should_include_link_text
